==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Architecture/Database/AmazonTimestream.md <==
# AmazonTimestream


```text
aws-20210730/Architecture/Database/AmazonTimestream
```

```text
include('aws-20210730/Architecture/Database/AmazonTimestream')
```



| Illustration | AmazonTimestream | AmazonTimestreamCard | AmazonTimestreamGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Architecture/Database/AmazonTimestream.png) | ![illustration for AmazonTimestream](../../../aws-20210730/Architecture/Database/AmazonTimestream.Local.png) | ![illustration for AmazonTimestreamCard](../../../aws-20210730/Architecture/Database/AmazonTimestreamCard.Local.png) | ![illustration for AmazonTimestreamGroup](../../../aws-20210730/Architecture/Database/AmazonTimestreamGroup.Local.png) |




## AmazonTimestream

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestream
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestream('AmazonTimestream', 'Amazon Timestream', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestream
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestream('AmazonTimestream', 'Amazon Timestream', 'an optional tech label')
@enduml
```

## AmazonTimestreamCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamCard
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamCard('AmazonTimestreamCard', 'Amazon Timestream Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamCard
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamCard('AmazonTimestreamCard', 'Amazon Timestream Card', 'an optional description')
@enduml
```

## AmazonTimestreamGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamGroup
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamGroup('AmazonTimestreamGroup', 'Amazon Timestream Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamGroup
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamGroup('AmazonTimestreamGroup', 'Amazon Timestream Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Architecture/Database/AmazonTimestream.md <==
# AmazonTimestream


```text
aws-20210730/Architecture/Database/AmazonTimestream
```

```text
include('aws-20210730/Architecture/Database/AmazonTimestream')
```



| Illustration | AmazonTimestream | AmazonTimestreamCard | AmazonTimestreamGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Architecture/Database/AmazonTimestream.png) | ![illustration for AmazonTimestream](../../../aws-20210730/Architecture/Database/AmazonTimestream.Local.png) | ![illustration for AmazonTimestreamCard](../../../aws-20210730/Architecture/Database/AmazonTimestreamCard.Local.png) | ![illustration for AmazonTimestreamGroup](../../../aws-20210730/Architecture/Database/AmazonTimestreamGroup.Local.png) |




## AmazonTimestream

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestream
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestream('AmazonTimestream', 'Amazon Timestream', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestream
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestream('AmazonTimestream', 'Amazon Timestream', 'an optional tech label')
@enduml
```

## AmazonTimestreamCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamCard
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamCard('AmazonTimestreamCard', 'Amazon Timestream Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamCard
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamCard('AmazonTimestreamCard', 'Amazon Timestream Card', 'an optional description')
@enduml
```

## AmazonTimestreamGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamGroup
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamGroup('AmazonTimestreamGroup', 'Amazon Timestream Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonTimestreamGroup
include('aws-20210730/Architecture/Database/AmazonTimestream')

' renders the element
AmazonTimestreamGroup('AmazonTimestreamGroup', 'Amazon Timestream Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
